@@ -81,7 +81,7 @@ def task_cl_bump() -> DoitTask:
     get_last_tag = 'git tag --list --sort=-creatordate | head -n 1'
     return debug_task([
         *_write_changelog(),
-        Interactive('poetry run cz bump --annotated-tag --no-verify'),
+        Interactive('poetry run cz bump --annotated-tag --no-verify --gpg-sign'),
         'git push origin --tags --no-verify',
         f'which gh >> /dev/null && gh release create --generate-notes $({get_last_tag})',
     ])
